@@ -5,13 +5,13 @@
 #   Name:
 #       GD::Graph::mixed.pm
 #
-# $Id: mixed.pm,v 1.10 2002/06/09 03:15:16 mgjv Exp $
+# $Id: mixed.pm,v 1.12.2.1 2005/12/19 06:03:59 ben Exp $
 #
 #==========================================================================
 
 package GD::Graph::mixed;
  
-$GD::Graph::mixed::VERSION = '$Revision: 1.10 $' =~ /\s([\d.]+)/;
+($GD::Graph::mixed::VERSION) = '$Revision: 1.12.2.1 $' =~ /\s([\d.]+)/;
 
 use strict;
  
@@ -30,6 +30,7 @@ use Carp;
 
 @GD::Graph::mixed::ISA = qw( 
     GD::Graph::axestype 
+    GD::Graph::bars
     GD::Graph::lines 
     GD::Graph::points 
 );
@@ -59,7 +60,7 @@ sub draw_data_set
 
     my $rc;
 
-    my $type = $self->{types}->[$ds-1] || $self->{default_type};
+    my $type = $self->types($ds);
 
     # Try to execute the draw_data_set function in the package
     # specified by type
@@ -70,6 +71,7 @@ sub draw_data_set
     if ($@)
     {
         carp "Set $ds, unknown type $type, assuming $self->{default_type}";
+	#carp "Error message: $@";
 
         $rc = eval '$self->GD::Graph::'.
             $self->{default_type}.'::draw_data_set(@_)';
@@ -86,7 +88,7 @@ sub draw_legend_marker
     my $self = shift;
     my $ds = $_[0];
 
-    my $type = $self->{types}->[$ds-1] || $self->{default_type};
+    my $type = $self->types($ds);
 
     eval '$self->GD::Graph::'.$type.'::draw_legend_marker(@_)';
 
@@ -94,4 +96,23 @@ sub draw_legend_marker
         $self->{default_type}.'::draw_legend_marker(@_)' if $@;
 }
 
+# undocumented as can be: returns the type-list (with the default
+# inserted as appropriate), or the type associated with a particular
+# (1-indexed) dataset number (undef if there is no such dataset).  The
+# range check means that this cannot be called when there is no
+# GD::Graph::Data object in $self->{_data}.
+
+sub types
+{
+    my $self = shift;
+    if ( defined $_[0] ) {
+        $_[0] > 0 && $_[0] <= $self->{_data}->num_sets
+          ? $self->{types}->[$_[0] - 1] || $self->{default_type}
+          : undef
+    } else {
+        map { $self->{types}->[$_ - 1] || $self->{default_type} }
+          1 .. $self->{_data}->num_sets;
+    }
+}
+
 "Just another true value";
